@@ -82,7 +82,8 @@ fn use_db_history(db_path: &Path, tick_rate: u64) -> Option<bool> {
         let tick = Duration::from_millis(tick_rate);
         if map.tick != tick {
             println!(
-                "Database tick: {} does not match supplied tick: {}.",
+                "Using Database:{:?}\nDatabase tick: {} does not match supplied tick: {}.",
+                db_path,
                 map.tick.as_millis(),
                 tick.as_millis()
             );
@@ -213,16 +214,14 @@ fn start_zenith(
             if !db_path.exists() {
                 debug!("Creating DB dir.");
                 fs::create_dir_all(db_path).expect("Couldn't Create DB dir.");
-            } else {
-                if !db_path.is_dir() {
-                    exit_with_message!(
-                        format!(
-                            "Expected the path to be a directory not a file: {}",
-                            db_path.to_string_lossy()
-                        ),
-                        1
-                    );
-                }
+            } else if !db_path.is_dir() {
+                exit_with_message!(
+                    format!(
+                        "Expected the path to be a directory not a file: {}",
+                        db_path.to_string_lossy()
+                    ),
+                    1
+                );
             }
             debug!("Creating Lock");
 
